# Generated by Django 4.0 on 2023-06-10 07:18

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("social_django", "0013_migrate_extra_data"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="usersocialauth",
            name="extra_data",
        ),
        migrations.RemoveField(
            model_name="partial",
            name="data",
        ),
    ]
