# Generated by Django 4.0 on 2023-06-10 07:10

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("social_django", "0011_alter_id_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="usersocialauth",
            name="extra_data_new",
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name="partial",
            name="data_new",
            field=models.JSONField(default=dict),
        ),
    ]
